#ifndef QT_QTWEBKIT_VERSION_H
#define QT_QTWEBKIT_VERSION_H

#define QTWEBKIT_VERSION_STR "5.212.0"
#define QTWEBKIT_VERSION_MAJOR 5
#define QTWEBKIT_VERSION_MINOR 212
#define QTWEBKIT_VERSION_PATCH 0
#define QTWEBKIT_VERSION ((5<<16)|(212<<8)|(0))

#endif
